@@ -51,7 +51,12 @@ def assign_hazard_values_to_exposure_data(hazard, exposure,
              If hazard and exposure layers are both of type raster,
              this attribute is ignored.
         * mode:
-             Interpolation mode for raster to point interpolation only
+             Interpolation mode for raster to point interpolation only.
+             Permissible values are 'linear' (default) which will employ
+             bilinear interpolation and 'constant' which will employ a
+             piecewise constant interpolation. This parameter is passed
+             all the way down to the underlying interpolation function
+             interpolate2d (module common/interpolation2d.py)
 
     Returns:
         Layer representing the exposure data with hazard levels assigned.
@@ -634,3 +639,58 @@ def make_circular_polygon(centers, radii, attributes=None):
                geometry_type='polygon')
 
     return Z
+
+
+def tag_polygons_by_grid(polygons, grid, threshold=0, tag='affected'):
+    """Tag polygons by raster values
+
+    Args:
+        * polygons: Polygon layer
+        * grid: Raster layer
+        * threshold: Threshold for grid value to tag polygon
+        * tag: Name of new tag
+
+    Returns:
+        Polygon layer: Same as input polygon but with extra attribute tag
+                       set according to grid values
+
+    """
+
+    verify(polygons.is_polygon_data)
+    verify(grid.is_raster)
+
+    polygon_attributes = polygons.get_data()
+    polygon_geometry = polygons.get_geometry(as_geometry_objects=True)
+
+    # Separate grid points by polygon
+    res = clip_grid_by_polygons(grid.get_data(),
+                                grid.get_geotransform(),
+                                polygon_geometry)
+
+    # Create new polygon layer with tag set according to grid values
+    # and threshold
+    new_attributes = []
+    for i, (_, values) in enumerate(res):
+        # For each polygon check if any grid value in it exceeds the threshold
+        affected = False
+        for val in values:
+            # Check each grid value in this polygon
+            if val > threshold:
+                affected = True
+
+        # Existing attributes for this polygon
+        attr = polygon_attributes[i].copy()
+
+        # Create tagged polygon feature
+        if affected:
+            attr[tag] = True
+        else:
+            attr[tag] = False
+
+        new_attributes.append(attr)
+
+    R = Vector(data=new_attributes,
+               projection=polygons.get_projection(),
+               geometry=polygon_geometry,
+               name='%s_tagged_by_%s' % (polygons.name, grid.name))
+    return R
