@@ -13,6 +13,7 @@ from safe.common.polygon import inside_polygon
 from safe.common.utilities import ugettext as tr
 from safe.common.tables import Table, TableCell, TableRow
 from utilities import pretty_string, remove_double_spaces
+from safe.common.utilities import OrderedDict
 
 LOGGER = logging.getLogger('InaSAFE')
 
@@ -201,7 +202,7 @@ def requirement_check(params, require_str, verbose=False):
         # Check that symbol is not a Python keyword
         if key in python_keywords.kwlist:
             msg = ('Error in plugin requirements'
-                   'Must not use Python keywords as params: %s' % (key))
+                   'Must not use Python keywords as params: %s' % key)
             #print msg
             #logger.error(msg)
             return False
@@ -354,7 +355,7 @@ def get_question(hazard_title, exposure_title, func):
 
     function_title = get_function_title(func)
     return (tr('In the event of <i>%(hazard)s</i> how many '
-              '<i>%(exposure)s</i> might <i>%(impact)s</i>')
+               '<i>%(exposure)s</i> might <i>%(impact)s</i>')
             % {'hazard': hazard_title.lower(),
                'exposure': exposure_title.lower(),
                'impact': function_title.lower()})
@@ -587,7 +588,7 @@ def get_plugins_as_table(dict_filter=None):
     table_body = []
     # use this list for avoiding wrong order in dict
     atts = ['category', 'subcategory', 'layertype',
-                           'datatype', 'unit']
+            'datatype', 'unit']
     header = TableRow([tr('Title'), tr('ID'), tr('Category'),
                        tr('Sub Category'), tr('Layer type'), tr('Data type'),
                        tr('Unit')],
@@ -610,6 +611,10 @@ def get_plugins_as_table(dict_filter=None):
 
             dict_req = parse_single_requirement(str(requirement))
 
+            # If the impact function is disabled, do not show it
+            if dict_req.get('disabled', False):
+                continue
+
             for myKey in dict_found.iterkeys():
                 myFilter = dict_filter.get(myKey, [])
                 if myKey == 'title':
@@ -648,7 +653,7 @@ def get_plugins_as_table(dict_filter=None):
                 row.append(key)
                 for myKey in atts:
                     myValue = pretty_string(dict_req.get(myKey,
-                                                not_found_value))
+                                                         not_found_value))
                     row.append(myValue)
                 table_body.append(TableRow(row))
 
@@ -683,6 +688,8 @@ def get_unique_values():
     plugins_dict = dict([(pretty_function_name(p), p)
                          for p in FunctionProvider.plugins])
     for key, func in plugins_dict.iteritems():
+        if not is_function_enabled(func):
+            continue
         dict_retval['title'].add(get_function_title(func))
         dict_retval['id'].add(key)
         for requirement in requirements_collect(func):
@@ -701,68 +708,6 @@ def get_unique_values():
     return dict_retval
 
 
-def get_dict_doc_func(func):
-    """Collect all doc string of func and return a beatiuful format of them
-    in a dictionary format.
-
-        Args:
-            * func : name of function
-        Returns:
-            * Dictionary contains:
-                synopsis : string (first line)
-                author : string (identified by :author)
-                rating : integer (identified by :rating)
-                param_req : list of param (identified by :param requires)
-                detail : detail description (identified by :detail)
-                citation : list of citation in string (identified by :citation)
-                limitation : string (identified by :limitation)
-    """
-    retval = {'synopsis': '',
-              'author': '',
-              'rating': '',
-              'param_req': [],
-              'detail': '',
-              'citation': [],
-              'limitation': ''}
-
-    plugins_dict = dict([(pretty_function_name(p), p)
-                         for p in FunctionProvider.plugins])
-    if func not in plugins_dict.keys():
-        return retval
-    else:
-        func = plugins_dict[func]
-
-    author_tag = ':author'
-    rating_tag = ':rating'
-    param_req_tag = ':param requires'
-    detail_tag = ':detail'
-    citation_tag = ':citation'
-    limitation_tag = ':limitation'
-
-    if hasattr(func, '__doc__') and func.__doc__:
-        doc_str = func.__doc__
-        for line in doc_str.split('\n'):
-            doc_line = remove_double_spaces(line)
-            doc_line = doc_line.strip()
-
-            if doc_line.startswith(author_tag):
-                retval['author'] = doc_line[len(author_tag) + 1:]
-            elif doc_line.startswith(rating_tag):
-                retval['rating'] = int(doc_line[len(rating_tag) + 1:])
-            elif doc_line.startswith(detail_tag):
-                retval['detail'] = doc_line[len(detail_tag) + 1:]
-            elif doc_line.startswith(limitation_tag):
-                retval['limitation'] = doc_line[len(limitation_tag) + 1:]
-            elif doc_line.startswith(param_req_tag):
-                retval['param_req'].append(doc_line[len(param_req_tag) + 1:])
-            elif doc_line.startswith(citation_tag):
-                retval['citation'].append(doc_line[len(citation_tag) + 1:])
-
-        retval['synopsis'] = remove_double_spaces(doc_str.split('\n')[0])
-
-    return retval
-
-
 def get_documentation(func):
     """Collect documentaion of a impact function and return it as a dictionary
 
@@ -778,12 +723,13 @@ def get_documentation(func):
                 citation : list of citation in string (function properties)
                 limitation : string (function properties)
     """
-    retval = {'unique_identifier': func}
+    retval = OrderedDict()
+    retval['unique_identifier'] = func
 
     plugins_dict = dict([(pretty_function_name(p), p)
                          for p in FunctionProvider.plugins])
     if func not in plugins_dict.keys():
-        return retval
+        return None
     else:
         func = plugins_dict[func]
 
@@ -796,9 +742,10 @@ def get_documentation(func):
     # citations must be a list
     citations = 'citations'
     detailed_description = 'detailed_description'
-    permissible_hazard_input = 'permissible_hazard_input'
-    permissible_exposure_input = 'permissible_exposure_input'
+    hazard_input = 'hazard_input'
+    exposure_input = 'exposure_input'
     limitation = 'limitation'
+    output = 'output'
 
     if hasattr(func, '__doc__') and func.__doc__:
         doc_str = func.__doc__
@@ -808,7 +755,7 @@ def get_documentation(func):
 
             if doc_line.startswith(author_tag):
                 retval['author'] = remove_double_spaces(
-                                        doc_line[len(author_tag) + 1:])
+                    doc_line[len(author_tag) + 1:])
             elif doc_line.startswith(rating_tag):
                 retval['rating'] = doc_line[len(rating_tag) + 1:]
     retval['title'] = get_function_title(func)
@@ -821,43 +768,32 @@ def get_documentation(func):
         retval[citations] = func.citations
     if hasattr(func, detailed_description):
         retval[detailed_description] = func.detailed_description
-    if hasattr(func, permissible_hazard_input):
-        retval[permissible_hazard_input] = func.permissible_hazard_input
-    if hasattr(func, permissible_exposure_input):
-        retval[permissible_exposure_input] = func.permissible_exposure_input
+    if hasattr(func, hazard_input):
+        retval[hazard_input] = func.hazard_input
+    if hasattr(func, exposure_input):
+        retval[exposure_input] = func.exposure_input
+    if hasattr(func, output):
+        retval[output] = func.output
     if hasattr(func, limitation):
         retval[limitation] = func.limitation
     return retval
 
 
-def format_int(x):
-    """Format integer with separator between thousands
-
-    From http://stackoverflow.com/questions/5513615/
-                add-thousands-separators-to-a-number
-
-    # FIXME (Ole)
-    Currently not using locale coz broken
-
-    Instead use this:
-    http://docs.python.org/library/string.html#formatspec
-
+def get_doc_string(func):
+    """Return doc string of an impact function
     """
+    return func.__doc__
 
-    # This is broken
-    #import locale
-    #locale.setlocale(locale.LC_ALL, '')  # Broken, why?
-    #s = locale.format('%d', x, 1)
 
-    import os
-    lang = os.getenv('LANG')
+def is_function_enabled(func):
+    """Check whether a function is enabled or not
+    :param func:
+    :return: False is disabled param is True
+    """
+    for requirement in requirements_collect(func):
+        dict_req = parse_single_requirement(str(requirement))
 
-    s = '{0:,}'.format(x)
-    #s = '{0:n}'.format(x)  # n means locale aware (read up on this)
-
-    # Quick solution for the moment
-    if lang == 'id':
-        # Replace commas with dots
-        s = s.replace(',', '.')
-
-    return s
+        # If the impact function is disabled, do not show it
+        if dict_req.get('disabled', False):
+            return False
+    return True
