@@ -1,8 +1,8 @@
-from safe.impact_functions.core import FunctionProvider
-from safe.impact_functions.core import get_hazard_layer, get_exposure_layer
-from safe.impact_functions.core import get_question
+from safe.common.utilities import OrderedDict
+from safe.impact_functions.core import (
+    FunctionProvider, get_hazard_layer, get_exposure_layer, get_question)
 from safe.storage.vector import Vector
-from safe.common.utilities import ugettext as tr
+from safe.common.utilities import (ugettext as tr, format_int)
 from safe.common.tables import Table, TableRow
 from safe.engine.interpolation import assign_hazard_values_to_exposure_data
 
@@ -23,10 +23,15 @@ class EarthquakeBuildingImpactFunction(FunctionProvider):
     """
 
     target_field = 'Shake_cls'
+    statistics_type = 'class_count'
+    statistics_classes = [0, 1, 2, 3]
     title = tr('Be affected')
-    parameters = {'low_threshold': 6,
-                  'medium_threshold': 7,
-                  'high_threshold': 8}
+    parameters = OrderedDict([('low_threshold', 6),
+                              ('medium_threshold', 7),
+                              ('high_threshold', 8),
+                              ('postprocessors', OrderedDict([
+                              ('AggregationCategorical', {'on': False})]))
+                              ])
 
     def run(self, layers):
         """Earthquake impact to buildings (e.g. from Open Street Map)
@@ -44,34 +49,34 @@ class EarthquakeBuildingImpactFunction(FunctionProvider):
         class_3 = tr('High')
 
         # Extract data
-        H = get_hazard_layer(layers)    # Depth
-        E = get_exposure_layer(layers)  # Building locations
+        my_hazard = get_hazard_layer(layers)    # Depth
+        my_exposure = get_exposure_layer(layers)  # Building locations
 
-        question = get_question(H.get_name(),
-                                E.get_name(),
+        question = get_question(my_hazard.get_name(),
+                                my_exposure.get_name(),
                                 self)
 
         # Define attribute name for hazard levels
         hazard_attribute = 'mmi'
 
         # Determine if exposure data have NEXIS attributes
-        attribute_names = E.get_attribute_names()
+        attribute_names = my_exposure.get_attribute_names()
         if ('FLOOR_AREA' in attribute_names and
             'BUILDING_C' in attribute_names and
-            'CONTENTS_C' in attribute_names):
+                'CONTENTS_C' in attribute_names):
             is_NEXIS = True
         else:
             is_NEXIS = False
 
         # Interpolate hazard level to building locations
-        I = assign_hazard_values_to_exposure_data(H, E,
-                                             attribute_name=hazard_attribute)
+        my_interpolate_result = assign_hazard_values_to_exposure_data(
+            my_hazard, my_exposure, attribute_name=hazard_attribute)
 
         # Extract relevant exposure data
-        #attribute_names = I.get_attribute_names()
-        attributes = I.get_data()
+        #attribute_names = my_interpolate_result.get_attribute_names()
+        attributes = my_interpolate_result.get_data()
 
-        N = len(I)
+        N = len(my_interpolate_result)
 
         # Calculate building impact
         lo = 0
@@ -82,7 +87,6 @@ class EarthquakeBuildingImpactFunction(FunctionProvider):
         for key in range(4):
             building_values[key] = 0
             contents_values[key] = 0
-
         for i in range(N):
             # Classify building according to shake level
             # and calculate dollar losses
@@ -109,7 +113,10 @@ class EarthquakeBuildingImpactFunction(FunctionProvider):
                 building_value = building_value_density * area
                 contents_value = contents_value_density * area
 
-            x = float(attributes[i][hazard_attribute])  # MMI
+            try:
+                x = float(attributes[i][hazard_attribute])  # MMI
+            except TypeError:
+                x = 0.0
             if t0 <= x < t1:
                 lo += 1
                 cls = 1
@@ -144,61 +151,71 @@ class EarthquakeBuildingImpactFunction(FunctionProvider):
                                     tr('Buildings value ($M)'),
                                     tr('Contents value ($M)')],
                                    header=True),
-                          TableRow([class_1, lo,
-                                    building_values[1],
-                                    contents_values[1]]),
-                          TableRow([class_2, me,
-                                    building_values[2],
-                                    contents_values[2]]),
-                          TableRow([class_3, hi,
-                                    building_values[3],
-                                    contents_values[3]])]
+                          TableRow([class_1, format_int(lo),
+                                    format_int(building_values[1]),
+                                    format_int(contents_values[1])]),
+                          TableRow([class_2, format_int(me),
+                                    format_int(building_values[2]),
+                                    format_int(contents_values[2])]),
+                          TableRow([class_3, format_int(hi),
+                                    format_int(building_values[3]),
+                                    format_int(contents_values[3])])]
         else:
             # Generate simple impact report for unspecific buildings
             table_body = [question,
                           TableRow([tr('Hazard Level'),
                                     tr('Buildings Affected')],
-                                    header=True),
-                          TableRow([class_1, str(lo)]),
-                          TableRow([class_2, str(me)]),
-                          TableRow([class_3, str(hi)])]
+                          header=True),
+                          TableRow([class_1, format_int(lo)]),
+                          TableRow([class_2, format_int(me)]),
+                          TableRow([class_3, format_int(hi)])]
 
         table_body.append(TableRow(tr('Notes'), header=True))
         table_body.append(tr('High hazard is defined as shake levels greater '
                              'than %i on the MMI scale.') % t2)
         table_body.append(tr('Medium hazard is defined as shake levels '
-                             'between %i and %i on the MMI scale.')
-                             % (t1, t2))
+                             'between %i and %i on the MMI scale.') % (t1, t2))
         table_body.append(tr('Low hazard is defined as shake levels '
-                             'between %i and %i on the MMI scale.')
-                             % (t0, t1))
+                             'between %i and %i on the MMI scale.') % (t0, t1))
         if is_NEXIS:
             table_body.append(tr('Values are in units of 1 million Australian '
                                  'Dollars'))
 
         impact_summary = Table(table_body).toNewlineFreeString()
         impact_table = impact_summary
-        map_title = tr('Buildings affected')
 
         # Create style
-        style_classes = [dict(label=class_1, min=1, max=1,
+        style_classes = [dict(label=class_1, value=t0,
                               colour='#ffff00', transparency=1),
-                         dict(label=class_2, min=2, max=2,
+                         dict(label=class_2, value=t1,
                               colour='#ffaa00', transparency=1),
-                         dict(label=class_3, min=3, max=3,
+                         dict(label=class_3, value=t2,
                               colour='#ff0000', transparency=1)]
         style_info = dict(target_field=self.target_field,
-                          style_classes=style_classes)
+                          style_classes=style_classes,
+                          style_type='categorizedSymbol')
+
+        # For printing map purpose
+        map_title = tr('Building affected by earthquake')
+        legend_notes = tr('The level of the impact is according to the '
+                          'threshold the user input.')
+        legend_units = tr('(mmi)')
+        legend_title = tr('Impact level')
 
         # Create vector layer and return
         V = Vector(data=attributes,
-                   projection=I.get_projection(),
-                   geometry=I.get_geometry(),
+                   projection=my_interpolate_result.get_projection(),
+                   geometry=my_interpolate_result.get_geometry(),
                    name=tr('Estimated buildings affected'),
                    keywords={'impact_summary': impact_summary,
                              'impact_table': impact_table,
                              'map_title': map_title,
-                             'target_field': self.target_field},
+                             'legend_notes': legend_notes,
+                             'legend_units': legend_units,
+                             'legend_title': legend_title,
+                             'target_field': self.target_field,
+                             'statistics_type': self.statistics_type,
+                             'statistics_classes': self.statistics_classes},
                    style_info=style_info)
 
         LOGGER.debug('Created vector layer  %s' % str(V))
