@@ -44,27 +44,6 @@ class AutoVivification(dict):
             value = self[_item] = type(self)()
             return value
 
-# read vulnerability information
-eng_filename = os.path.join(path, 'itb_vulnerability_eng.csv')
-non_eng_filename = os.path.join(path, 'itb_vulnerability_non_eng.csv')
-
-vul_curves = AutoVivification()
-# Non-Engineere dbuildings
-a = open(non_eng_filename).readlines()
-for item in a[1:]:
-    tmp = item.strip('\n').split(',')
-    idx = tmp[0]  # structural type index
-    vul_curves[idx]['median'] = float(tmp[5])
-    vul_curves[idx]['beta'] = float(tmp[6])
-
-# Engineered buildings
-a = open(eng_filename).readlines()
-for item in a[1:]:
-    tmp = item.strip('\n').split(',')
-    idx = tmp[0]  # structural type index
-    vul_curves[idx]['median'] = float(tmp[6])
-    vul_curves[idx]['beta'] = float(tmp[7])
-
 
 class ITBEarthquakeBuildingDamageFunction(FunctionProvider):
     """Risk plugin for ITB earthquake damage to buildings in Padang
@@ -78,7 +57,8 @@ class ITBEarthquakeBuildingDamageFunction(FunctionProvider):
     :param requires category=='exposure' and \
                     subcategory=='structure' and \
                     layertype=='vector' and \
-                    datatype in ['osm', 'itb', 'sigab']
+                    datatype in ['osm', 'itb', 'sigab'] and \
+                    disabled=='True'
     """
 
     title = tr('Be damaged depending on building type')
@@ -91,6 +71,30 @@ class ITBEarthquakeBuildingDamageFunction(FunctionProvider):
         H = get_hazard_layer(layers)    # Ground shaking
         E = get_exposure_layer(layers)  # Building locations
 
+
+        # read vulnerability information
+        eng_filename = os.path.join(path, 'itb_vulnerability_eng.csv')
+        non_eng_filename = os.path.join(path, 'itb_vulnerability_non_eng.csv')
+
+
+        vul_curves = AutoVivification()
+        # Non-Engineere dbuildings
+        a = open(non_eng_filename).readlines()
+        for item in a[1:]:
+            tmp = item.strip('\n').split(',')
+            idx = tmp[0]  # structural type index
+            vul_curves[idx]['median'] = float(tmp[5])
+            vul_curves[idx]['beta'] = float(tmp[6])
+
+        # Engineered buildings
+        a = open(eng_filename).readlines()
+        for item in a[1:]:
+            tmp = item.strip('\n').split(',')
+            idx = tmp[0]  # structural type index
+            vul_curves[idx]['median'] = float(tmp[6])
+            vul_curves[idx]['beta'] = float(tmp[7])
+
+
         datatype = E.get_keywords()['datatype']
         vclass_tag = 'ITB_Class'
         if datatype.lower() == 'osm':
@@ -168,23 +172,22 @@ class ITBEarthquakeBuildingDamageFunction(FunctionProvider):
         # Create report
         Hname = H.get_name()
         Ename = E.get_name()
-        impact_summary = ('<b>In case of "%s" the estimated impact to '
-                           '"%s" '
-                           'is&#58;</b><br><br><p>' % (Hname, Ename))
-        impact_summary += ('<table border="0" width="320px">'
-                   '   <tr><th><b>%s</b></th><th><b>%s</b></th></th>'
-                    '   <tr></tr>'
-                    '   <tr><td>%s&#58;</td><td>%i</td></tr>'
-                    '   <tr><td>%s (<10%%)&#58;</td><td>%i</td></tr>'
-                    '   <tr><td>%s (10-33%%)&#58;</td><td>%i</td></tr>'
-                    '   <tr><td>%s (33-66%%)&#58;</td><td>%i</td></tr>'
-                    '   <tr><td>%s (66-100%%)&#58;</td><td>%i</td></tr>'
-                    '</table></font>' % (tr('Buildings'), tr('Total'),
-                                    tr('All'), N,
-                                    tr('No damage'), count0,
-                                    tr('Low damage'), count10,
-                                    tr('Medium damage'), count25,
-                                    tr('High damage'), count50))
+        impact_summary = (
+            '<b>In case of "%s" the estimated impact to "%s" is&#58;</b><br>'
+            '<br><p>' % (Hname, Ename))
+        impact_summary += (
+            '<table border="0" width="320px">'
+            '   <tr><th><b>%s</b></th><th><b>%s</b></th></th>'
+            '   <tr></tr>'
+            '   <tr><td>%s&#58;</td><td>%i</td></tr>'
+            '   <tr><td>%s (<10%%)&#58;</td><td>%i</td></tr>'
+            '   <tr><td>%s (10-33%%)&#58;</td><td>%i</td></tr>'
+            '   <tr><td>%s (33-66%%)&#58;</td><td>%i</td></tr>'
+            '   <tr><td>%s (66-100%%)&#58;</td><td>%i</td></tr>'
+            '</table></font>' % (tr('Buildings'), tr('Total'), tr('All'), N,
+                                 tr('No damage'), count0, tr('Low damage'),
+                                 count10, tr('Medium damage'), count25,
+                                 tr('High damage'), count50))
         impact_summary += '<br>'  # Blank separation row
         impact_summary += '<b>' + tr('Assumption') + '&#58;</b><br>'
         # This is the proper text:
@@ -193,11 +196,13 @@ class ITBEarthquakeBuildingDamageFunction(FunctionProvider):
         #  'Australia and Institute of Teknologi Bandung.'))
         #tr('Unreinforced masonry is assumed where no '
         #  'structural information is available.'))
-        impact_summary += tr('Levels of impact are defined by post 2009 '
-                            'Padang earthquake survey conducted by Geoscience '
-                            'Australia and Institute of Teknologi Bandung.')
-        impact_summary += tr('Unreinforced masonry is assumed where no '
-                            'structural information is available.')
+        impact_summary += tr(
+            'Levels of impact are defined by post 2009 Padang earthquake '
+            'survey conducted by Geoscience Australia and Institute of '
+            'Teknologi Bandung.')
+        impact_summary += tr(
+            'Unreinforced masonry is assumed where no structural information '
+            'is available.')
         # Create style
         style_classes = [dict(label=tr('No damage'), min=0, max=10,
                               colour='#00ff00', transparency=0),
