@@ -1,14 +1,23 @@
-from safe.impact_functions.core import FunctionProvider
-from safe.impact_functions.core import get_hazard_layer, get_exposure_layer
-from safe.impact_functions.core import get_question
-from safe.impact_functions.core import format_int
+import numpy
+from safe.common.utilities import OrderedDict
+import logging
+from safe.impact_functions.core import (
+    FunctionProvider,
+    get_hazard_layer,
+    get_exposure_layer,
+    get_question)
 from safe.storage.raster import Raster
-from safe.common.utilities import (ugettext as tr,
-                                   get_defaults)
+from safe.common.utilities import (
+    ugettext as tr,
+    get_defaults,
+    format_int,
+    humanize_class,
+    create_classes,
+    create_label)
 from safe.common.tables import Table, TableRow
 from safe.common.exceptions import InaSAFEError
 
-import numpy
+LOGGER = logging.getLogger('InaSAFE')
 
 
 class ITBFatalityFunction(FunctionProvider):
@@ -30,7 +39,7 @@ class ITBFatalityFunction(FunctionProvider):
     In this study, the same functional form as Allen (2009) is adopted
     to express fatality rate as a function of intensity (see Eq. 10 in the
     report). The Matlab built-in function (fminsearch) for  Nelder-Mead
-    algorithm is used to estimate the model parameters. The objective
+    algorithm was used to estimate the model parameters. The objective
     function (L2G norm) that is minimised during the optimisation is the
     same as the one used by Jaiswal et al. (2010).
 
@@ -66,6 +75,9 @@ class ITBFatalityFunction(FunctionProvider):
         - consistency between selected GMPEs with those in use by BMKG.
           These issues will be addressed by ITB team in the final report.
 
+    Note: Because of these caveats, decisions should not be made solely on
+    the information presented here and should always be verified by ground
+    truthing and other reliable information sources.
 
     :author Hadi Ghasemi
     :rating 3
@@ -82,36 +94,94 @@ class ITBFatalityFunction(FunctionProvider):
     """
 
     title = tr('Die or be displaced')
+    synopsis = tr(
+        'To asses the impact of earthquake on population based on earthquake '
+        'model developed by ITB')
+    citations = tr(
+        ' * Indonesian Earthquake Building-Damage and Fatality Models and '
+        '   Post Disaster Survey Guidelines Development Bali, 27-28 '
+        '   February 2012, 54pp.\n'
+        ' * Allen, T. I., Wald, D. J., Earle, P. S., Marano, K. D., '
+        '   Hotovec, A. J., Lin, K., and Hearne, M., 2009. An Atlas '
+        '   of ShakeMaps and population exposure catalog for '
+        '   earthquake loss modeling, Bull. Earthq. Eng. 7, 701-718.\n'
+        ' * Jaiswal, K., and Wald, D., 2010. An empirical model for '
+        '   global earthquake fatality estimation, Earthq. Spectra '
+        '   26, 1017-1037.\n')
+    limitation = tr(
+        ' - The model is based on limited number of observed fatality '
+        '   rates during 4 past fatal events. \n'
+        ' - The model clearly over-predicts the fatality rates at '
+        '   intensities higher than VIII.\n'
+        ' - The model only estimates the expected fatality rate '
+        '   for a given intensity level; however the associated '
+        '   uncertainty for the proposed model is not addressed.\n'
+        ' - There are few known mistakes in developing the current '
+        '   model:\n\n'
+        '   * rounding MMI values to the nearest 0.5,\n'
+        '   * Implementing Finite-Fault models of candidate events, and\n'
+        '   * consistency between selected GMPEs with those in use by '
+        '     BMKG.\n')
+    actions = tr(
+        'Provide details about the population will be die or displaced')
+    detailed_description = tr(
+        'This model was developed by Institut Tecknologi Bandung (ITB) '
+        'and implemented by Dr Hadi Ghasemi, Geoscience Australia\n'
+        'Algorithm:\n'
+        'In this study, the same functional form as Allen (2009) is '
+        'adopted o express fatality rate as a function of intensity '
+        '(see Eq. 10 in the report). The Matlab built-in function '
+        '(fminsearch) for  Nelder-Mead algorithm was used to estimate '
+        'the model parameters. The objective function (L2G norm) that '
+        'is minimized during the optimisation is the same as the one '
+        'used by Jaiswal et al. (2010).\n'
+        'The coefficients used in the indonesian model are x=0.62275231, '
+        'y=8.03314466, zeta=2.15')
     defaults = get_defaults()
-    parameters = dict(x=0.62275231, y=8.03314466,  # Model coefficients
-                      # Rates of people displaced for each MMI level
-                      displacement_rate={1: 0, 2: 0, 3: 0, 4: 0, 5: 0, 6: 1.0,
-                                         7: 1.0, 8: 1.0, 9: 1.0, 10: 1.0},
-                      # Threshold below which layer should be transparent
-                      tolerance=0.01,
-                      calculate_displaced_people=True,
-                      postprocessors={'Gender': {'on': True},
-                          'Age': {'on': True,
-                              'params':
-                                  {'youth_ratio': defaults['YOUTH_RATIO'],
-                                   'adult_ratio': defaults['ADULT_RATIO'],
-                                   'elder_ratio': defaults['ELDER_RATIO']}}})
+    parameters = OrderedDict([
+        ('x', 0.62275231), ('y', 8.03314466),  # Model coefficients
+        # Rates of people displaced for each MMI level
+        ('displacement_rate', {1: 0, 2: 0, 3: 0, 4: 0, 5: 0, 6: 1.0,
+                               7: 1.0, 8: 1.0, 9: 1.0, 10: 1.0}),
+        ('mmi_range', range(2, 10)),
+        ('step', 0.5),
+        # Threshold below which layer should be transparent
+        ('tolerance', 0.01),
+        ('calculate_displaced_people', True),
+        ('postprocessors', OrderedDict([
+            ('Gender', {'on': True}),
+            ('Age', {
+                'on': True,
+                'params': OrderedDict([
+                    ('youth_ratio', defaults['YOUTH_RATIO']),
+                    ('adult_ratio', defaults['ADULT_RATIO']),
+                    ('elder_ratio', defaults['ELDER_RATIO'])])})]))])
+
+    def fatality_rate(self, mmi):
+        """
+        ITB method to compute fatality rate
+        :param x: model coefficient.
+        :param y: model coefficient.
+        """
+        # As per email discussion with Ole, Trevor, Hadi, mmi < 4 will have
+        # a fatality rate of 0 - Tim
+        if mmi < 4:
+            return 0
+
+        x = self.parameters['x']
+        y = self.parameters['y']
+        return numpy.power(10.0, x * mmi - y)
 
     def run(self, layers):
         """Indonesian Earthquake Fatality Model
 
         Input
           layers: List of layers expected to contain
-              H: Raster layer of MMI ground shaking
-              P: Raster layer of population density
+              my_hazard: Raster layer of MMI ground shaking
+              my_exposure: Raster layer of population density
 
         """
 
-        # Establish model coefficients
-        x = self.parameters['x']
-        y = self.parameters['y']
-
-        # Define percentages of people being displaced at each mmi level
         displacement_rate = self.parameters['displacement_rate']
 
         # Tolerance for transparency
@@ -126,29 +196,31 @@ class ITBFatalityFunction(FunctionProvider):
                                 self)
 
         # Extract data grids
-        H = intensity.get_data()   # Ground Shaking
-        P = population.get_data(scaling=True)  # Population Density
+        my_hazard = intensity.get_data()   # Ground Shaking
+        my_exposure = population.get_data(scaling=True)  # Population Density
 
         # Calculate population affected by each MMI level
         # FIXME (Ole): this range is 2-9. Should 10 be included?
-        mmi_range = range(2, 10)
+
+        mmi_range = self.parameters['mmi_range']
         number_of_exposed = {}
         number_of_displaced = {}
         number_of_fatalities = {}
 
-        # Calculate fatality rates for observed Intensity values (H
+        # Calculate fatality rates for observed Intensity values (my_hazard
         # based on ITB power model
-        R = numpy.zeros(H.shape)
+        R = numpy.zeros(my_hazard.shape)
         for mmi in mmi_range:
-
-            # Identify cells where MMI is in class i
-            mask = (H > mmi - 0.5) * (H <= mmi + 0.5)
-
-            # Count population affected by this shake level
-            I = numpy.where(mask, P, 0)
+            # Identify cells where MMI is in class i and
+            # count population affected by this shake level
+            I = numpy.where(
+                (my_hazard > mmi - self.parameters['step']) * (
+                    my_hazard <= mmi + self.parameters['step']),
+                my_exposure, 0)
 
             # Calculate expected number of fatalities per level
-            fatality_rate = numpy.power(10.0, x * mmi - y)
+            fatality_rate = self.fatality_rate(mmi)
+
             F = fatality_rate * I
 
             # Calculate expected number of displaced people per level
@@ -176,11 +248,15 @@ class ITBFatalityFunction(FunctionProvider):
         R[R < tolerance] = numpy.nan
 
         # Total statistics
-        total = int(round(numpy.nansum(P.flat) / 1000) * 1000)
+        total = int(round(numpy.nansum(my_exposure.flat) / 1000) * 1000)
 
         # Compute number of fatalities
         fatalities = int(round(numpy.nansum(number_of_fatalities.values())
                                / 1000)) * 1000
+        # As per email discussion with Ole, Trevor, Hadi, total fatalities < 50
+        # will be rounded down to 0 - Tim
+        if fatalities < 50:
+            fatalities = 0
 
         # Compute number of people displaced due to building collapse
         displaced = int(round(numpy.nansum(number_of_displaced.values())
@@ -190,7 +266,6 @@ class ITBFatalityFunction(FunctionProvider):
         table_body = [question]
 
         # Add total fatality estimate
-        #s = str(int(fatalities)).rjust(10)
         s = format_int(fatalities)
         table_body.append(TableRow([tr('Number of fatalities'), s],
                                    header=True))
@@ -235,13 +310,12 @@ class ITBFatalityFunction(FunctionProvider):
                       [tr('Clean Water [l]'), format_int(water)],
                       [tr('Family Kits'), format_int(family_kits)],
                       [tr('Toilets'), format_int(toilets)]]
-        impact_table = Table(table_body).toNewlineFreeString()
 
         table_body.append(TableRow(tr('Action Checklist:'), header=True))
         if fatalities > 0:
             table_body.append(tr('Are there enough victim identification '
                                  'units available for %s people?') %
-                                 format_int(fatalities))
+                              format_int(fatalities))
         if displaced > 0:
             table_body.append(tr('Are there enough shelters and relief items '
                                  'available for %s people?')
@@ -254,56 +328,72 @@ class ITBFatalityFunction(FunctionProvider):
 
         # Extend impact report for on-screen display
         table_body.extend([TableRow(tr('Notes'), header=True),
-                           tr('Total population: %i') % total,
+                           tr('Total population: %s') % format_int(total),
                            tr('People are considered to be displaced if '
                               'they experience and survive a shake level'
                               'of more than 5 on the MMI scale '),
                            tr('Minimum needs are defined in BNPB '
-                             'regulation 7/2008')])
-
-        impact_summary = Table(table_body).toNewlineFreeString()
-        map_title = tr('People in need of evacuation')
+                              'regulation 7/2008'),
+                           tr('The fatality calculation assumes that '
+                              'no fatalities occur for shake levels below 4 '
+                              'and fatality counts of less than 50 are '
+                              'disregarded.'),
+                           tr('All values are rounded up to the nearest '
+                              'integer in order to avoid representing human '
+                              'lives as fractionals.')])
 
         table_body.append(TableRow(tr('Notes'), header=True))
         table_body.append(tr('Fatality model is from '
-                            'Institute of Teknologi Bandung 2012.'))
+                             'Institute of Teknologi Bandung 2012.'))
         table_body.append(tr('Population numbers rounded to nearest 1000.'))
 
+        # Result
         impact_summary = Table(table_body).toNewlineFreeString()
         impact_table = impact_summary
-        map_title = tr('Earthquake impact to population')
 
-        # Create style info dynamically
-        classes = numpy.linspace(numpy.nanmin(R.flat[:]),
-                                 numpy.nanmax(R.flat[:]), 5)
+        # Create style
+        colours = ['#EEFFEE', '#FFFF7F', '#E15500', '#E4001B', '#730000']
+        classes = create_classes(R.flat[:], len(colours))
+        interval_classes = humanize_class(classes)
+        style_classes = []
+        for i in xrange(len(colours)):
+            style_class = dict()
+            style_class['label'] = create_label(interval_classes[i])
+            style_class['quantity'] = classes[i]
+            if i == 0:
+                transparency = 100
+            else:
+                transparency = 30
+            style_class['transparency'] = transparency
+            style_class['colour'] = colours[i]
+            style_classes.append(style_class)
 
-        style_classes = [dict(colour='#EEFFEE', quantity=classes[0],
-                              transparency=100,
-                              label=tr('%.2f people/cell') % classes[0]),
-                         dict(colour='#FFFF7F', quantity=classes[1],
-                              transparency=30),
-                         dict(colour='#E15500', quantity=classes[2],
-                              transparency=30,
-                              label=tr('%.2f people/cell') % classes[2]),
-                         dict(colour='#E4001B', quantity=classes[3],
-                              transparency=30),
-                         dict(colour='#730000', quantity=classes[4],
-                              transparency=30,
-                              label=tr('%.2f people/cell') % classes[4])]
         style_info = dict(target_field=None,
-                          style_classes=style_classes)
+                          style_classes=style_classes,
+                          style_type='rasterStyle')
 
-        # Create new layer and return
+        # For printing map purpose
+        map_title = tr('Earthquake impact to population')
+        legend_notes = tr('Thousand separator is represented by \'.\'')
+        legend_units = tr('(people per cell)')
+        legend_title = tr('Population density')
+
+        # Create raster object and return
         L = Raster(R,
                    projection=population.get_projection(),
                    geotransform=population.get_geotransform(),
                    keywords={'impact_summary': impact_summary,
                              'total_population': total,
                              'total_fatalities': fatalities,
+                             'fatalites_per_mmi': number_of_fatalities,
+                             'exposed_per_mmi': number_of_exposed,
+                             'displaced_per_mmi': number_of_displaced,
                              'impact_table': impact_table,
-                             'map_title': map_title},
-                   name=tr('Estimated displaced population'),
+                             'map_title': map_title,
+                             'legend_notes': legend_notes,
+                             'legend_units': legend_units,
+                             'legend_title': legend_title},
+                   name=tr('Estimated displaced population per cell'),
                    style_info=style_info)
 
-        # Maybe return a shape file with contours instead
         return L
