@@ -49,13 +49,8 @@ _pseudo_inf = float(99999999)
 
 
 class Vector(Layer):
-    """Class for abstraction of vector data.
-    """
+    """InaSAFE representation of vector data.
 
-    def __init__(self, data=None, projection=None, geometry=None,
-                 geometry_type=None, name=None, keywords=None,
-                 style_info=None, sublayer=None):
-        """Initialise object with either geometry or filename
 
         Args:
             * data: Can be either
@@ -89,10 +84,11 @@ class Vector(Layer):
                   data file.
 
         Returns:
-            * An instance of class Vector.
+            * InaSAFE vector layer instance
 
         Raises:
-            * Propogates any exceptions encountered.
+            * TypeError, ReadLayerError, WriteLayerError, InaSAFEError,
+              GetDataError
 
         Notes:
 
@@ -114,6 +110,17 @@ class Vector(Layer):
             If polygons have holes, their geometry must be passed in as a
             list of polygon geometry objects
             (as defined in module geometry.py)
+
+    """
+
+    def __init__(self, data=None, projection=None, geometry=None,
+                 geometry_type=None, name=None, keywords=None,
+                 style_info=None, sublayer=None):
+        """Initialise object with either geometry or filename
+
+        NOTE: Doc strings in constructor are not harvested and exposed in
+        online documentation. Hence the details are specified in the
+        class docstring.
         """
 
         # Invoke common layer constructor
@@ -150,11 +157,15 @@ class Vector(Layer):
             else:
                 self.geometry_type = get_geometry_type(geometry, geometry_type)
 
-                # Convert to objects if input is a list of simple arrays
                 if self.is_polygon_data:
+                    # Convert to objects if input is a list of simple arrays
                     self.geometry = [Polygon(outer_ring=x) for x in geometry]
                 else:
-                    self.geometry = geometry
+                    # Convert to list if input is an array
+                    if isinstance(geometry, numpy.ndarray):
+                        self.geometry = geometry.tolist()
+                    else:
+                        self.geometry = geometry
 
             if data is None:
                 # Generate default attribute as OGR will do that anyway
@@ -891,15 +902,18 @@ class Vector(Layer):
 
     @property
     def is_point_data(self):
-        return self.is_vector and self.geometry_type == ogr.wkbPoint
+        return self.is_vector and (self.geometry_type == ogr.wkbPoint or
+            self.geometry_type == ogr.wkbPoint25D)
 
     @property
     def is_line_data(self):
-        return self.is_vector and self.geometry_type == ogr.wkbLineString
+        return self.is_vector and (self.geometry_type == ogr.wkbLineString or
+            self.geometry_type == ogr.wkbLineString25D)
 
     @property
     def is_polygon_data(self):
-        return self.is_vector and self.geometry_type == ogr.wkbPolygon
+        return self.is_vector and (self.geometry_type == ogr.wkbPolygon or
+            self.geometry_type == ogr.wkbPolygon25D)
 
     @property
     def is_multi_polygon_data(self):
